@@ -7,7 +7,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Tobias Prinz <tobias.prinz@open-xchange.com>
  */
@@ -801,7 +801,7 @@ define('io.ox/tours/main',
                 }
 
                 link.append(
-                    $('<a target="_blank" href="" role="menuitem" tabindex="1">').text(
+                    $('<a target="_blank" href="" role="menuitem">').text(
                         //#. Tour name; general introduction
                         gt('Getting started')
                     )
@@ -829,7 +829,7 @@ define('io.ox/tours/main',
 
             require(['settings!io.ox/tours', 'io.ox/tours/main'], function (tourSettings, thisIsStupid) {
                 tourLink.append(
-                    $('<a target="_blank" href="" role="menuitem" tabindex="1">').text(gt('Guided tour for this app'))
+                    $('<a target="_blank" href="" role="menuitem">').text(gt('Guided tour for this app'))
                     .on('click', function (e) {
                         var currentApp = ox.ui.App.getCurrentApp(),
                             currentType = currentApp.attributes.name;
